@@ -2,7 +2,7 @@
 
 from hashlib import sha1
 import requests
-import simplejson as json
+import json
 import tempfile
 import shutil
 import os
@@ -402,7 +402,7 @@ class WxApi(WxBaseApi):
                           {'openid': user_id, 'to_groupid': group_id})
 
     def create_menu(self, menus):
-        return self._post('menu/create', menus, ctype='text')
+        return self._post('menu/create', menus)
 
     def get_menu(self):
         return self._get('menu/get')
